@@ -34,7 +34,6 @@ sys.path.insert(0, os.path.join(os.path.abspath('.'), '_exts'))
 # extensions coming with Sphinx (named 'sphinx.ext.*') or your custom ones.
 extensions = ['sphinx.ext.viewcode',
               'sphinx.ext.graphviz',
-              'sphinxcontrib.seqdiag',
               'sphinxcontrib.apidoc',
               'sphinxcontrib.rsvgconverter',
               'oslo_config.sphinxext',
@@ -43,7 +42,8 @@ extensions = ['sphinx.ext.viewcode',
               'oslo_policy.sphinxpolicygen',
               'automated_steps',
               'openstackdocstheme',
-              'web_api_docstring'
+              'web_api_docstring',
+              'redfish_interop',
               ]
 
 # sphinxcontrib.apidoc options
@@ -58,8 +58,16 @@ apidoc_excluded_paths = [
 ]
 apidoc_separate_modules = True
 
+autodoc_default_options = {
+    'special-members': '__call__',
+}
+
+redfish_interop_source = \
+    '../../redfish-interop-profiles/OpenStackIronicProfile.v1_1_0.json'
+redfish_interop_output_dir = 'admin/drivers/redfish/'
+
 openstackdocs_repo_name = 'openstack/ironic'
-openstackdocs_use_storyboard = True
+openstackdocs_use_storyboard = False
 openstackdocs_pdf_link = True
 openstackdocs_projects = [
     'bifrost',
@@ -163,7 +171,3 @@ latex_documents = [
 
 # Allow deeper levels of nesting for \begin...\end stanzas
 latex_elements = {'maxlistdepth': 10}
-
-# -- Options for seqdiag ------------------------------------------------------
-
-seqdiag_html_image_format = "SVG"
