@@ -109,9 +109,9 @@ class TestAgentClient(base.TestCase):
                           self.node)
 
     def test__get_command_body(self):
-        expected = json.dumps({'name': 'prepare_image', 'params': {}})
+        expected = json.dumps({'name': 'get_clean_steps', 'params': {}})
         self.assertEqual(expected,
-                         self.client._get_command_body('prepare_image', {}))
+                         self.client._get_command_body('get_clean_steps', {}))
 
     def test__command(self):
         response_data = {'status': 'ok'}
@@ -488,6 +488,28 @@ class TestAgentClient(base.TestCase):
             timeout=60,
             verify=False)
 
+    @mock.patch('os.path.exists', autospec=True, return_value=True)
+    def test__command_verify_disable_in_driver_info(self, mock_exists):
+        response_data = {'status': 'ok'}
+        self.client.session.post.return_value = MockResponse(response_data)
+        method = 'standby.run_image'
+        image_info = {'image_id': 'test_image'}
+        params = {'image_info': image_info}
+
+        self.node.driver_info['agent_verify_ca'] = False
+
+        url = self.client._get_command_url(self.node)
+        body = self.client._get_command_body(method, params)
+
+        response = self.client._command(self.node, method, params)
+        self.assertEqual(response, response_data)
+        self.client.session.post.assert_called_once_with(
+            url,
+            data=body,
+            params={'wait': 'false'},
+            timeout=60,
+            verify=False)
+
     @mock.patch('os.path.exists', autospec=True, return_value=False)
     def test__command_verify_invalid_file(self, mock_exists):
         response_data = {'status': 'ok'}
@@ -501,7 +523,8 @@ class TestAgentClient(base.TestCase):
         self.assertRaises(exception.InvalidParameterValue,
                           self.client._command, self.node, method, params)
 
-    def test__command_poll(self):
+    @mock.patch('time.sleep', autospec=True)
+    def test__command_poll(self, mock_sleep):
         response_data = {'status': 'ok'}
         final_status = MockCommandStatus('SUCCEEDED', name='run_image')
         self.client.session.post.return_value = MockResponse(response_data)
@@ -529,23 +552,26 @@ class TestAgentClient(base.TestCase):
             params={'wait': 'false'},
             timeout=60,
             verify=True)
-        self.client.session.get.assert_called_with(url, timeout=60,
+        self.client.session.get.assert_called_with(url, params={}, timeout=60,
                                                    verify=True)
+        mock_sleep.assert_called_with(CONF.agent.command_wait_interval)
 
     def test_get_commands_status(self):
-        with mock.patch.object(self.client.session, 'get',
-                               autospec=True) as mock_get:
-            res = mock.MagicMock(spec_set=['json'])
-            res.json.return_value = {'commands': []}
-            mock_get.return_value = res
-            self.assertEqual([], self.client.get_commands_status(self.node))
-            agent_url = self.node.driver_internal_info.get('agent_url')
-            mock_get.assert_called_once_with(
-                '%(agent_url)s/%(api_version)s/commands' % {
-                    'agent_url': agent_url,
-                    'api_version': CONF.agent.agent_api_version},
-                timeout=CONF.agent.command_timeout,
-                verify=True)
+        if not mock._is_instance_mock(self.client.session):
+            mock.patch.object(self.client.session, 'get',
+                              autospec=True).start()
+        mock_get = self.client.session.get
+
+        res = mock.MagicMock(spec_set=['json'])
+        res.json.return_value = {'commands': []}
+        mock_get.return_value = res
+        self.assertEqual([], self.client.get_commands_status(self.node))
+        agent_url = self.node.driver_internal_info.get('agent_url')
+        mock_get.assert_called_once_with(
+            '%(agent_url)s/%(api_version)s/commands/' % {
+                'agent_url': agent_url,
+                'api_version': CONF.agent.agent_api_version},
+            params={}, verify=True, timeout=CONF.agent.command_timeout)
 
     def test_get_commands_status_retries(self):
         res = mock.MagicMock(spec_set=['json'])
@@ -568,100 +594,22 @@ class TestAgentClient(base.TestCase):
     def test_get_commands_status_verify(self, mock_exists):
         self.node.driver_info['agent_verify_ca'] = '/path/to/agent.crt'
 
-        with mock.patch.object(self.client.session, 'get',
-                               autospec=True) as mock_get:
-            res = mock.MagicMock(spec_set=['json'])
-            res.json.return_value = {'commands': []}
-            mock_get.return_value = res
-            self.assertEqual([], self.client.get_commands_status(self.node))
-            agent_url = self.node.driver_internal_info.get('agent_url')
-            mock_get.assert_called_once_with(
-                '%(agent_url)s/%(api_version)s/commands' % {
-                    'agent_url': agent_url,
-                    'api_version': CONF.agent.agent_api_version},
-                timeout=CONF.agent.command_timeout,
-                verify='/path/to/agent.crt')
+        if not mock._is_instance_mock(self.client.session):
+            mock.patch.object(self.client.session, 'get',
+                              autospec=True).start()
+        mock_get = self.client.session.get
 
-    def test_prepare_image(self):
-        self.client._command = mock.MagicMock(spec_set=[])
-        image_info = {'image_id': 'image'}
-        params = {'image_info': image_info}
-
-        self.client.prepare_image(self.node,
-                                  image_info,
-                                  wait=False)
-        self.client._command.assert_called_once_with(
-            node=self.node, method='standby.prepare_image',
-            params=params, poll=False)
-
-    def test_prepare_image_with_configdrive(self):
-        self.client._command = mock.MagicMock(spec_set=[])
-        configdrive_url = 'http://swift/configdrive'
-        self.node.instance_info['configdrive'] = configdrive_url
-        image_info = {'image_id': 'image'}
-        params = {
-            'image_info': image_info,
-            'configdrive': configdrive_url,
-        }
-
-        self.client.prepare_image(self.node,
-                                  image_info,
-                                  wait=False)
-        self.client._command.assert_called_once_with(
-            node=self.node, method='standby.prepare_image',
-            params=params, poll=False)
-
-    def test_prepare_image_with_wait(self):
-        self.client._command = mock.MagicMock(spec_set=[])
-        image_info = {'image_id': 'image'}
-        params = {'image_info': image_info}
-
-        self.client.prepare_image(self.node,
-                                  image_info,
-                                  wait=True)
-        self.client._command.assert_called_once_with(
-            node=self.node, method='standby.prepare_image',
-            params=params, poll=True)
-
-    def test_start_iscsi_target(self):
-        self.client._command = mock.MagicMock(spec_set=[])
-        iqn = 'fake-iqn'
-        port = agent_client.DEFAULT_IPA_PORTAL_PORT
-        wipe_disk_metadata = False
-        params = {'iqn': iqn, 'portal_port': port,
-                  'wipe_disk_metadata': wipe_disk_metadata}
-
-        self.client.start_iscsi_target(self.node, iqn)
-        self.client._command.assert_called_once_with(
-            node=self.node, method='iscsi.start_iscsi_target',
-            params=params, wait=True)
-
-    def test_start_iscsi_target_custom_port(self):
-        self.client._command = mock.MagicMock(spec_set=[])
-        iqn = 'fake-iqn'
-        port = 3261
-        wipe_disk_metadata = False
-        params = {'iqn': iqn, 'portal_port': port,
-                  'wipe_disk_metadata': wipe_disk_metadata}
-
-        self.client.start_iscsi_target(self.node, iqn, portal_port=port)
-        self.client._command.assert_called_once_with(
-            node=self.node, method='iscsi.start_iscsi_target',
-            params=params, wait=True)
-
-    def test_start_iscsi_target_wipe_disk_metadata(self):
-        self.client._command = mock.MagicMock(spec_set=[])
-        iqn = 'fake-iqn'
-        port = agent_client.DEFAULT_IPA_PORTAL_PORT
-        wipe_disk_metadata = True
-        params = {'iqn': iqn, 'portal_port': port,
-                  'wipe_disk_metadata': wipe_disk_metadata}
-
-        self.client.start_iscsi_target(self.node, iqn,
-                                       wipe_disk_metadata=wipe_disk_metadata)
-        self.client._command.assert_called_once_with(
-            node=self.node, method='iscsi.start_iscsi_target',
-            params=params, wait=True)
+        res = mock.MagicMock(spec_set=['json'])
+        res.json.return_value = {'commands': []}
+        mock_get.return_value = res
+        self.assertEqual([], self.client.get_commands_status(self.node))
+        agent_url = self.node.driver_internal_info.get('agent_url')
+        mock_get.assert_called_once_with(
+            '%(agent_url)s/%(api_version)s/commands/' % {
+                'agent_url': agent_url,
+                'api_version': CONF.agent.agent_api_version},
+            params={}, verify='/path/to/agent.crt',
+            timeout=CONF.agent.command_timeout)
 
     def _test_install_bootloader(self, root_uuid, efi_system_part_uuid=None,
                                  prep_boot_part_uuid=None):
@@ -719,6 +667,53 @@ class TestAgentClient(base.TestCase):
             node=self.node, method='clean.execute_clean_step',
             params=expected_params)
 
+    def test_get_service_steps(self):
+        self.client._command = mock.MagicMock(spec_set=[])
+        ports = []
+        expected_params = {
+            'node': self.node.as_dict(secure=True),
+            'ports': []
+        }
+
+        self.client.get_service_steps(self.node,
+                                      ports)
+        self.client._command.assert_called_once_with(
+            node=self.node, method='service.get_service_steps',
+            params=expected_params, wait=True)
+
+    def test_get_service_steps_older_client(self):
+        self.client._command = mock.MagicMock(spec_set=[])
+        self.client._command.side_effect = exception.AgentAPIError('meow')
+        ports = []
+        expected_params = {
+            'node': self.node.as_dict(secure=True),
+            'ports': []
+        }
+
+        self.client.get_service_steps(self.node,
+                                      ports)
+        self.client._command.assert_called_once_with(
+            node=self.node, method='service.get_service_steps',
+            params=expected_params, wait=True)
+
+    def test_execute_service_step(self):
+        self.client._command = mock.MagicMock(spec_set=[])
+        ports = []
+        step = {'priority': 10, 'step': 'erase_devices', 'interface': 'deploy'}
+        expected_params = {
+            'step': step,
+            'node': self.node.as_dict(secure=True),
+            'ports': [],
+            'service_version':
+                self.node.driver_internal_info['hardware_manager_version']
+        }
+        self.client.execute_service_step(step,
+                                         self.node,
+                                         ports)
+        self.client._command.assert_called_once_with(
+            node=self.node, method='service.execute_service_step',
+            params=expected_params)
+
     def test_power_off(self):
         self.client._command = mock.MagicMock(spec_set=[])
         self.client.power_off(self.node)
